@@ -20,7 +20,10 @@ extern crate dmntk_feel;
 extern crate dmntk_model;
 #[macro_use]
 extern crate lazy_static;
+#[macro_use]
+extern crate thiserror;
 
+mod errors;
 mod workspace;
 
 pub use workspace::{deploy_definitions, evaluate_artifact};
